manifest_all_groups: Return all defined optional dependency groups in a manifest...

View source: R/parse.R

manifest_all_groupsR Documentation

Return all defined optional dependency groups in a manifest file

Description

Return all defined optional dependency groups in a manifest file

Usage

manifest_all_groups(path = "rproject.toml")

Arguments

path

Path to the rproject.toml file.

Value

A character vector of group names (without "-dependencies")

Examples

manifest_all_groups(path = system.file(package = 'manifesto', 'minimal.toml'))

manifesto documentation built on May 6, 2026, 1:06 a.m.