manifest_check: Check if the installed packages match the manifest...

View source: R/check.R

manifest_checkR Documentation

Check if the installed packages match the manifest requirements

Description

Check if the installed packages match the manifest requirements

Usage

manifest_check(path = "rproject.toml", groups = NULL)

Arguments

path

Path to the TOML manifest file. Defaults to "rproject.toml".

groups

Optional dependency groups to include. Defaults to NULL (core only).

Value

A data.frame reporting installed version, required version, and status.

Examples

manifest_check(system.file(package = 'manifesto', 'minimal.toml'))

manifesto documentation built on May 6, 2026, 1:06 a.m.