| manifest_from_loaded | R Documentation |
Captures all currently loaded packages in the R session and generates
a manifesto-style TOML manifest. Package versions can either reflect
their current loaded versions, or use a wildcard (*) to accept any.
manifest_from_loaded(
path,
include_base = FALSE,
min_version = c("loaded", "*"),
r_version = current_r_version()
)
path |
Optional path to write the manifest. If missing, a temporary |
include_base |
Logical. Whether to include base packages. Defaults to FALSE. |
min_version |
Whether to require exact loaded versions ( |
r_version |
Optional R version settings. Defaults to |
Base packages are excluded by default to minimize boilerplate.
Path to the generated TOML file (invisibly).
path <- manifest_from_loaded()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.