| manifest_install | R Documentation |
Install packages from a manifesto manifest
manifest_install(path = "rproject.toml", groups = NULL, dry_run = FALSE)
path |
Path to the |
groups |
Optional character vector of dependency groups to include (e.g., "dev", "workshop"). |
dry_run |
If |
Invisibly returns a character vector of package references that were installed.
manifest_install(
path = system.file(package = 'manifesto', 'minimal.toml'),
dry_run = TRUE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.