Learn R Programming

manifesto (version 0.0.2)

manifest_all_groups: Return all defined optional dependency groups in a manifest file

Description

Return all defined optional dependency groups in a manifest file

Usage

manifest_all_groups(path = "rproject.toml")

Value

A character vector of group names (without "-dependencies")

Arguments

path

Path to the rproject.toml file.

Examples

Run this code
manifest_all_groups(path = system.file(package = 'manifesto', 'minimal.toml'))

Run the code above in your browser using DataLab