Learn R Programming

manifesto (version 0.0.2)

manifest_check: Check if the installed packages match the manifest requirements

Description

Check if the installed packages match the manifest requirements

Usage

manifest_check(path = "rproject.toml", groups = NULL)

Value

A data.frame reporting installed version, required version, and status.

Arguments

path

Path to the TOML manifest file. Defaults to "rproject.toml".

groups

Optional dependency groups to include. Defaults to NULL (core only).

Examples

Run this code
manifest_check(system.file(package = 'manifesto', 'minimal.toml'))

Run the code above in your browser using DataLab