| manifest_from_description | R Documentation |
Parses fields from a DESCRIPTION file and generates a corresponding
TOML manifest with [project], [environment], and dependency groups.
manifest_from_description(
description = "DESCRIPTION",
path,
include_empty_groups = FALSE
)
description |
Path to the DESCRIPTION file. |
path |
Optional output file path. Defaults to a temporary |
include_empty_groups |
Whether to include empty dependency sections. |
By default, both Depends and Imports are mapped to [dependencies].
Suggests, LinkingTo, and Enhances are mapped to their own optional groups.
Path to the generated TOML file (invisibly).
path <- manifest_from_description(system.file(package = 'cli', 'DESCRIPTION'))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.