powered by
Parses fields from a DESCRIPTION file and generates a corresponding TOML manifest with [project], [environment], and dependency groups.
[project]
[environment]
manifest_from_description( description = "DESCRIPTION", path, include_empty_groups = FALSE )
Path to the generated TOML file (invisibly).
Path to the DESCRIPTION file.
Optional output file path. Defaults to a temporary .toml file.
.toml
Whether to include empty dependency sections.
By default, both Depends and Imports are mapped to [dependencies]. Suggests, LinkingTo, and Enhances are mapped to their own optional groups.
Depends
Imports
[dependencies]
Suggests
LinkingTo
Enhances
path <- manifest_from_description(system.file(package = 'cli', 'DESCRIPTION'))
Run the code above in your browser using DataLab