Learn R Programming

manifesto (version 0.0.2)

manifest_install: Install packages from a manifesto manifest

Description

Install packages from a manifesto manifest

Usage

manifest_install(path = "rproject.toml", groups = NULL, dry_run = FALSE)

Value

Invisibly returns a character vector of package references that were installed.

Arguments

path

Path to the rproject.toml file. Defaults to "rproject.toml" in the current directory.

groups

Optional character vector of dependency groups to include (e.g., "dev", "workshop").

dry_run

If TRUE, show what would be installed but do not install anything.

Examples

Run this code
manifest_install(
  path = system.file(package = 'manifesto', 'minimal.toml'),
  dry_run = TRUE
)

Run the code above in your browser using DataLab