powered by
Install packages from a manifesto manifest
manifest_install(path = "rproject.toml", groups = NULL, dry_run = FALSE)
Invisibly returns a character vector of package references that were installed.
Path to the rproject.toml file. Defaults to "rproject.toml" in the current directory.
rproject.toml
Optional character vector of dependency groups to include (e.g., "dev", "workshop").
If TRUE, show what would be installed but do not install anything.
TRUE
manifest_install( path = system.file(package = 'manifesto', 'minimal.toml'), dry_run = TRUE )
Run the code above in your browser using DataLab